@@ -17,6 +17,8 @@ state if the connection to RTM drops.
 
 from __future__ import print_function
 from contextlib import contextmanager
+import satori.rtm.auth as auth
+from satori.rtm.exceptions import AuthError
 import satori.rtm.internal_queue as queue
 import threading
 
@@ -40,7 +42,7 @@ class Client(object):
             self, endpoint, appkey,
             fail_count_threshold=float('inf'),
             reconnect_interval=1, max_reconnect_interval=300,
-            observer=None, restore_auth_on_reconnect=False,
+            observer=None, restore_auth_on_reconnect=True,
             max_queue_size=20000):
         r"""
 
@@ -70,7 +72,7 @@ Parameters
       Set this property with client.observer or in the `make_client(*args,
       **kwargs)` or `Client(*args, **kwargs)` methods.
     * restore_auth_on_reconnect {boolean} optional - Whether to restore
-      authentication after reconnects. Default is False.
+      authentication after reconnects. Default is True.
     * max_queue_size {int} optional - this parameter limits the amount of
       concurrent requests in order to avoid 'out of memory' situation.
       For example is max_queue_size is 10 and the client code sends 11
@@ -89,7 +91,8 @@ Syntax
         """
 
         assert endpoint
-        assert endpoint.startswith('ws://') or endpoint.startswith('wss://')
+        assert endpoint.startswith('ws://') or endpoint.startswith('wss://'),\
+            'Endpoint must start with "ws(s)://" but "%s" does not' % endpoint
 
         self._queue = queue.Queue(maxsize=max_queue_size)
 
@@ -555,7 +558,8 @@ Description
     connection. The SDK stops and then closes the WebSocket connection when the
     statement completes or terminates due to an error.
 
-    This function takes the same parameters as the Client constructor.
+    This function takes the same parameters as the Client constructor plus
+    optional `auth_delegate`.
 
     To use this function, import it from the client module::
 
@@ -584,13 +588,15 @@ Parameters
       Set this property with client.observer or in the `make_client(*args,
       **kwargs)` or `Client(*args, **kwargs)` methods.
     * restore_auth_on_reconnect {boolean} optional - Whether to restore
-      authentication after reconnects. Default is False.
+      authentication after reconnects. Default is True.
     * max_queue_size {int} optional - this parameter limits the amount of
       concurrent requests in order to avoid 'out of memory' situation.
       For example is max_queue_size is 10 and the client code sends 11
       publish requests so fast that by the time it sends 11th one the reply
       for the first one has not yet arrived, this 11th call to `client.publish`
       will throw the `satori.rtm.client.Full` exception.
+    * auth_delegate {AuthDelegate} [optional] - if auth_delegate parameter is
+      present, the client yielded by make_client will be already authenticated.
 
 Syntax
     ::
@@ -709,10 +715,12 @@ callback function::
     """
 
     observer = kwargs.get('observer')
+    auth_delegate = kwargs.get('auth_delegate')
+    if 'auth_delegate' in kwargs:
+        del kwargs['auth_delegate']
 
     client = Client(*args, **kwargs)
     ready_event = threading.Event()
-    disposed_event = threading.Event()
 
     class Observer(ClientStateObserver):
         def on_enter_connected(self):
@@ -723,10 +731,6 @@ callback function::
             ClientStateObserver.on_enter_stopped(self)
             ready_event.set()
 
-        def on_enter_disposed(self):
-            ClientStateObserver.on_enter_disposed(self)
-            disposed_event.set()
-
     client.observer = Observer()
     client.start()
     if not ready_event.wait(70):
@@ -743,6 +747,27 @@ callback function::
         raise RuntimeError(
             "Client connection error: {0}".format(
                 client.last_connecting_error()))
+
+    auth_mailbox = []
+
+    def auth_callback(auth_result):
+        auth_mailbox.append(auth_result)
+        ready_event.set()
+
+    if auth_delegate:
+        client.authenticate(auth_delegate, callback=auth_callback)
+
+        if not ready_event.wait(20):
+            client.dispose()
+            raise AuthError('Authentication process has timed out')
+
+        auth_result = auth_mailbox[0]
+
+        if type(auth_result) == auth.Error:
+            raise AuthError(auth_result.message)
+
+        logger.debug('Auth success in make_client')
+
     try:
         client.observer = observer
         yield client
